<?php

abstract class ipay88_over_the_counter_Abstract extends WC_Payment_Gateway
{
    public function __construct()
    {
        $this->plugin_path = IPAY88_OVER_THE_COUNTER_PLUGIN_PATH;

        // Load the settings.
        $this->init_settings();
        $this->init_form_fields();
    }

    abstract public function init_configs($isPingback);

    protected function get_template($templateFileName, $data = array())
    {
        if (file_exists($this->plugin_path . 'templates/' . $templateFileName)) 
		{
            $content = file_get_contents($this->plugin_path . 'templates/' . $templateFileName);
        
		    foreach ($data as $key => $var) 
			{
                $content = str_replace('{{' . $key . '}}', $var, $content);
            }
            
			return $content;
        }
		
        return false;
    }

	//billing address
    protected function get_billing_address($order) 
	{
        $billing = $order->get_data()['billing'];

        return array(	'billing_city'          => $billing['city'],
						'billing_phone'         => $billing['phone'],
						'billing_state'         => $billing['state'],
						'shipping_address_1'    => $billing['address_1'],
						'shipping_country'      => $billing['country'],
						'billing_postcode'      => $billing['postcode'],
						'billing_email'         => $billing['email'],
						'billing_first_name'    => $billing['first_name'],
						'billing_last_name'     => $billing['last_name'],
					);
    }

	//shipping address
    protected function get_shipping_address($order) 
	{
        $shipping = $order->get_data()['shipping'];

        return array(	'shipping_city'          => $shipping['city'],
						'shipping_phone'         => $shipping['phone'],
						'shipping_state'         => $shipping['state'],
						'shipping_address_1'   	 => $shipping['address_1'],
						'shipping_country'       => $shipping['country'],
						'shipping_postcode'      => $shipping['postcode'],
						'shipping_email'         => $shipping['email'],
						'shipping_first_name'    => $shipping['first_name'],
						'shipping_last_name'     => $shipping['last_name']
					);
    }
	
	//customer profile
    protected function prepare_user_profile_data($order)
    {
        return array(	'customer[city]'		=> $order->billing_city,
						'customer[phone]' 		=> $order->billing_phone,
						'customer[state]' 		=> $order->billing_state,
						'customer[address]' 	=> $order->shipping_address_1,
						'customer[country]' 	=> $order->shipping_country,
						'customer[zip]' 		=> $order->billing_postcode,
						'customer[username]' 	=> $order->billing_email,
						'customer[firstname]' 	=> $order->billing_first_name,
						'customer[lastname]' 	=> $order->billing_last_name,
						'email' 				=> $order->billing_email,
					);
    }

    // Display administrative fields under the Payment Gateways tab in the Settings page
    function init_form_fields()
    {
        $this->form_fields = include($this->plugin_path.'includes/admin/settings/ipay88.php');
    }

    // Displays a short description to the user during checkout
    function payment_fields3()
    {
        $this->form();
    }

    function payment_fields()
    {
        echo $this->get_ipay88_over_the_counter_Wiget();
    }

    protected function get_ipay88_over_the_counter_Wiget()
	{
        $payment_methods	= $this->get_ipay88_payment_methods();
		$description		= $this->get_ipay88_description();
        $indo 				= new ipay88_over_the_counter_Indonesia();
		
        $indo->setImagePath(IPAY88_OVER_THE_COUNTER_PLUGIN_URL.'/assets/images');
		
		$imagePath 			= IPAY88_OVER_THE_COUNTER_PLUGIN_URL.'/assets/images';
        $wiget 				= $indo->getWiget($payment_methods, $description, $imagePath);

        return $wiget;
    }

    protected function get_ipay88_payment_methods() 
	{
        $indo 				= new ipay88_over_the_counter_Indonesia();
        $configKeys 		= $indo->getBanksConfigs();
        $payment_methods 	= array();

        foreach ($configKeys as $key) 
		{
            if($this->settings[$key] == ipay88_over_the_counter_Indonesia::PAYMENT_METHOD_ENABLE) 
			{
                $payment_methods[$key] = $this->settings[$key];
            }
        }
		
        return $payment_methods;
    }
	
	protected function get_ipay88_description() 
	{
		$description 	= $this->getConfigOptionByKey('description');
		
        return $description;
    }

    // Displays text like introduction, instructions in the admin area of the widget
    public function admin_options()
    {
        ob_start();
        
		$this->generate_settings_html();
        $settings = ob_get_contents();
        
		ob_clean();

        echo $this->get_template('admin/options.html', array( 'title' 		=> $this->method_title,
															  'description' => $this->method_description,
															  'settings' 	=> $settings
															));
    }

    function getRealClientIP()
    {
        if (function_exists('getallheaders')) 
		{
            $headers = getallheaders();
        } 
		
		else 
		{
            $headers = $_SERVER;
        }

        //Get the forwarded IP if it exists
        if (array_key_exists('X-Forwarded-For', $headers) && filter_var($headers['X-Forwarded-For'], FILTER_VALIDATE_IP, FILTER_FLAG_IPV4)) 
		{
            $the_ip = $headers['X-Forwarded-For'];
        } 
		
		elseif (array_key_exists('HTTP_X_FORWARDED_FOR', $headers) && filter_var($headers['HTTP_X_FORWARDED_FOR'], FILTER_VALIDATE_IP, FILTER_FLAG_IPV4)) 
		{
            $the_ip = $headers['HTTP_X_FORWARDED_FOR'];
        } 
		
		elseif (array_key_exists('Cf-Connecting-Ip', $headers)) 
		{
            $the_ip = $headers['Cf-Connecting-Ip'];
        } 
		
		else 
		{
            $the_ip = filter_var($_SERVER['REMOTE_ADDR'], FILTER_VALIDATE_IP, FILTER_FLAG_IPV4);
        }

        return $the_ip;
    }

    // Outputs fields for entering eCheck information.
    public function form() 
	{
        $fields = array();

        $default_fields = array( 'routing-number' => '<p class="form-row form-row-first">
                <label for="' . esc_attr( $this->id ) . '-routing-number">' . esc_html__( 'Routing number', 'woocommerce' ) . ' <span class="required">*</span></label>
                <input id="' . esc_attr( $this->id ) . '-routing-number" class="input-text wc-echeck-form-routing-number" type="text" maxlength="9" autocomplete="off" placeholder="&bull;&bull;&bull;&bull;&bull;&bull;&bull;&bull;&bull;" name="' . esc_attr( $this->id ) . '-routing-number" />
            </p>',
            'account-number' => '<p class="form-row form-row-wide">
                <label for="' . esc_attr( $this->id ) . '-account-number">' . esc_html__( 'Account number', 'woocommerce' ) . ' <span class="required">*</span></label>
                <input id="' . esc_attr( $this->id ) . '-account-number" class="input-text wc-echeck-form-account-number" type="text" autocomplete="off" name="' . esc_attr( $this->id ) . '-account-number" maxlength="17" />
            </p>',
        );

        $fields = wp_parse_args( $fields, apply_filters( 'woocommerce_echeck_form_fields', $default_fields, $this->id ) );
        ?>

    	<fieldset id="<?php echo esc_attr( $this->id ); ?>-cc-form" class='wc-echeck-form wc-payment-form'>
        <?php do_action( 'woocommerce_echeck_form_start', $this->id );
		
        foreach($fields as $field) 
		{
            echo $field;
        }
        ?>
        <?php do_action( 'woocommerce_echeck_form_end', $this->id ); ?>
        
        <div class="clear"></div>
        </fieldset><?php
    }
	
	function getConfigOptionByKey($key) 
	{
        return $this->settings[$key];
    }
}