<?php

defined('ABSPATH') or exit();
 /*
 * Plugin Name: iPay88 Over The Counter Payment
 * Plugin URI: https://docs.ipay88.co.id/woocommerce
 * Description: Allows you to use iPay88 Over The Counter Payment with the WooCommerce plugin.
 * Version:  1.6.1
 * Author: iPay88 Indonesia
 * Author URI: https://www.ipay88.co.id/
 * Text Domain: hhttps://www.ipay88.co.id/
 * License: The MIT License (MIT)
 *
 */

define('IPAY88_OVER_THE_COUNTER_TEXT_DOMAIN', 'ipay88-over-the-counter-for-woocommerce');
define('IPAY88_OVER_THE_COUNTER_DEFAULT_SUCCESS_PINGBACK_VALUE', 'OK');
define('IPAY88_OVER_THE_COUNTER_ORDER_STATUS_PENDING', 'wc-pending');
define('IPAY88_OVER_THE_COUNTER_ORDER_STATUS_COMPLETED', 'wc-completed');
define('IPAY88_OVER_THE_COUNTER_ORDER_STATUS_PROCESSING', 'wc-processing');
define('IPAY88_OVER_THE_COUNTER_PLUGIN_PATH', plugin_dir_path(__FILE__));
define('IPAY88_OVER_THE_COUNTER_PLUGIN_URL', plugins_url('', __FILE__));


function load_ipay88_over_the_counter_payments() 
{
	if (!class_exists('WC_Payment_Gateway')) return; // Nothing happens here is WooCommerce is not loaded

    include(IPAY88_OVER_THE_COUNTER_PLUGIN_PATH . '/lib/ipay88-over-the-counter-php/Autoload.php');
    include(IPAY88_OVER_THE_COUNTER_PLUGIN_PATH . '/includes/class-ipay88-over-the-counter-abstract.php');
    include(IPAY88_OVER_THE_COUNTER_PLUGIN_PATH . '/includes/class-ipay88-over-the-counter-gateway.php');

    function ipay88_over_the_counter_payments($methods) 
	{
        $methods[] = 'ipay88_over_the_counter_Gateway';
        return $methods;
    }

    add_filter('woocommerce_payment_gateways', 'ipay88_over_the_counter_payments');
}

add_action('plugins_loaded', 'load_ipay88_over_the_counter_payments', 0);

/**
 * Add ipay88_over_the_counter Scripts
 */
function ipay88_over_the_counter_scripts() 
{
    wp_register_script('placeholder', IPAY88_OVER_THE_COUNTER_PLUGIN_URL.'/assets/js/payment.js', array('jquery'), '1', true);
    wp_enqueue_script('placeholder');
}

add_action('wp_enqueue_scripts', 'ipay88_over_the_counter_scripts');

/**
 * Require the woocommerce plugin installed first
 */
function ipay88_over_the_counter_child_plugin_notice() 
{ ?>
	<div class="error">
    <p><?php echo __("Sorry, but iPay88 Over The Counter Payment Plugin requires the Woocommerce plugin to be installed and active.", IPAY88_OVER_THE_COUNTER_TEXT_DOMAIN)?></p>
    </div>
<?php
}

function ipay88_over_the_counter_child_plugin_has_parent_plugin() 
{
	if (is_admin() && current_user_can('activate_plugins') && !is_plugin_active('woocommerce/woocommerce.php')) 
	{
        add_action('admin_notices', 'pw_child_plugin_notice');

        deactivate_plugins(plugin_basename(__FILE__));
        if (isset($_GET['activate'])) 
		{
            unset($_GET['activate']);
        }
    }
}

add_action('admin_init', 'ipay88_over_the_counter_child_plugin_has_parent_plugin');

/**
 * Adds plugin page links
 *
 * @since 1.0.0
 * @param array $links all plugin links
 * @return array $links all plugin links + our custom links (i.e., "Settings")
 */
function wc_ipay88_over_the_counter_gateway_plugin_links( $links ) 
{
    $plugin_links = array(
        '<a href="' . admin_url( 'admin.php?page=wc-settings&tab=checkout&section=ipay88_over_the_counter' ) . '">' . __( 'Setting', 'ipay88_over_the_counter' ) . '</a>'
    );
    return array_merge( $plugin_links, $links );
}

add_filter( 'plugin_action_links_' . plugin_basename( __FILE__ ), 'wc_ipay88_over_the_counter_gateway_plugin_links' );